==> nextcloud-16.0.1.zip: nextcloud/apps/password_policy/l10n/tr.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Parola en az %s karakter uzunluğunda olmalıdır",
    "Password needs to contain at least one lower and one upper case character." : "Parolada en az bir küçük ve bir büyük harf bulunmalıdır.",
    "Password needs to contain at least one numeric character." : "Parolada en az bir rakam bulunmalıdır.",
    "Password needs to contain at least one special character." : "Parolada en az bir simge karakteri bulunmalıdır.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Yazdığınız parola sık kullanılan 1.000.000 parola içinde. Lütfen eşsiz bir parola seçin.",
    "Password is present in compromised password list. Please choose a different password." : "Yazdığınız parola bilinen parolalar listesinde. Lütfen başka bir parola seçin.",
    "Password policy" : "Parola ilkesi",
    "Allows admins to configure a password policy" : "Yöneticilerin bir parola ilkesi yapılandırmasını sağlar",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Yöneticilerin parolalar için en kısa uzunluk gibi çeşitli ön koşullar belirleyebilmesini sağlar.",
    "Minimal length" : "En az uzunluk",
    "Forbid common passwords" : "Sık kullanılan parolalar kullanılamasın",
    "Enforce upper and lower case characters" : "Parolada büyük ve küçük harfler bulunsun",
    "Enforce numeric characters" : "Parolada rakam bulunsun",
    "Enforce special characters" : "Parolada simge karakterleri bulunsun",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Parolalar haveibeenpwned.com üzerindeki bilinen parolalar listesi ile denetlensin",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Bu denetim paroladan bir sağlama değeri üretir ve ilk 5 karakterini haveibeenpwned.com API uygulamasına göndererek bu 5 karakter ile başlayan karmaların listesini alır. Ardından Nexctcloud kopyasında parola karmasının sonuç kümesinde olup olmadığını denetler."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-17.0.6.zip: nextcloud/apps/password_policy/l10n/tr.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Parolanın süresi doldu, lütfen sıfırlamak için parolayı unuttum yöntemini kullanın",
    "Password must not have been used recently before." : "Parola son kullandığınız parolalardan farklı olmalıdır.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Yazdığınız parola sık kullanılan 1.000.000 parola içinde. Lütfen eşsiz bir parola seçin.",
    "Password is present in compromised password list. Please choose a different password." : "Yazdığınız parola bilinen parolalar listesinde. Lütfen başka bir parola seçin.",
    "Password needs to be at least %s characters long" : "Parola en az %s karakter uzunluğunda olmalıdır",
    "Password needs to contain at least one numeric character." : "Parolada en az bir rakam bulunmalıdır.",
    "Password needs to contain at least one special character." : "Parolada en az bir simge karakteri bulunmalıdır.",
    "Password needs to contain at least one lower and one upper case character." : "Parolada en az bir küçük ve bir büyük harf bulunmalıdır.",
    "Password policy" : "Parola ilkesi",
    "Allows admins to configure a password policy" : "Yöneticilerin bir parola ilkesi yapılandırmasını sağlar",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Yöneticilerin parolalar için en kısa uzunluk gibi çeşitli ön koşullar belirleyebilmesini sağlar.",
    "Minimal length" : "En az uzunluk",
    "User password history" : "Kullanıcının parola geçmişi",
    "days until user password expires" : "kullanıcı parolasının süresi dolana kadarki günlerin sayısı",
    "Forbid common passwords" : "Sık kullanılan parolalar kullanılamasın",
    "Enforce upper and lower case characters" : "Parolada büyük ve küçük harfler bulunsun",
    "Enforce numeric characters" : "Parolada rakam bulunsun",
    "Enforce special characters" : "Parolada simge karakterleri bulunsun",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Parolalar haveibeenpwned.com üzerindeki bilinen parolalar listesi ile denetlensin",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Bu denetim paroladan bir sağlama değeri üretir ve ilk 5 karakterini haveibeenpwned.com API uygulamasına göndererek bu 5 karakter ile başlayan karmaların listesini alır. Ardından Nexctcloud kopyasında parola karmasının sonuç kümesinde olup olmadığını denetler."
},
"nplurals=2; plural=(n > 1);");
